@@ -25,6 +25,8 @@
 #include <termios.h>
 #include <sys/time.h>
 #include <signal.h>
+#include <ctype.h>
+#include <string.h>
 
 #include <glib.h>
 
@@ -138,7 +140,9 @@ int handy_set_comm_param()
 
 	/* choose raw output */
 	// options.c_oflag &= ~OPOST;	
+#if defined(OLCUC)
 	options.c_oflag &= ~OLCUC;
+#endif
 	options.c_oflag &= ~ONLCR;
 	options.c_oflag &= ~OCRNL;
 	// options.c_oflag &= ~NOCR;
@@ -309,7 +313,18 @@ int brl_ser_send_data (char *Data, int DataSize, short Blocking)
 {
 	int n;
 
+	/* When putting code here, move the 'tmp' variable out of the
+           conditional! */
+#if defined(OLCUC)
 	n = write (fdSerial, Data, DataSize);
+#else
+	char tmp[DataSize];
+	memcpy(tmp, Data, DataSize);
+	for (n = 0; n < DataSize; n++)
+		if (islower(tmp[n]))
+			tmp[n] = toupper(tmp[n]);
+	n = write (fdSerial, tmp, DataSize);
+#endif
 	if (Blocking) tcdrain(fdSerial);	
 	
 	if (n < 0)
